function analogFilmProcessYourlogin(videoFilePath, startTime, endTime, crop, ...
   outputFolderPath, height)
%% Test function for benchmarking. This function generates nFrames noisy
% pictures to outputFolderPath folder. Pictures are created in nSteps because of
% memory limitations.

% create output folder
if logical(exist(outputFolderPath, 'dir')) % check if folder exist
   % delete folder if exist with its content
   rmdir(outputFolderPath, 's');
end
% create empty output folder
mkdir(outputFolderPath)
% number of frames to create
nFrames = 1e2;
% order of numbers in pictures names
nameNumberLength = ceil(log10(nFrames+1));
% compute final frame size preseving its aspect ratio
frameSize = [height round(height*crop(3)/crop(4))];
% generate noisy figures in nSteps
nSteps = 5;
numberOfImagesInStep = diff(ceil(linspace(1, nFrames+1, nSteps)));
% number in name of file
numberOfFrameName = 1;
for iStep = 1:nSteps-1
   % number of images in this step
   nFramesInThisStep = numberOfImagesInStep(iStep);
   % generate random data
   frameData = randi(intmax('uint8'), [frameSize, 3, nFramesInThisStep], 'uint8');
   % save continuously individual frames
   for iFrameInStep = 1:nFramesInThisStep
      framePath = fullfile(outputFolderPath, ...
         ['frame_', sprintf(['%0', int2str(nameNumberLength), 'i'], numberOfFrameName), '.jpg']);
      imwrite(frameData(:, :, :, iFrameInStep), framePath, 'jpg', 'quality', 70);
      numberOfFrameName = numberOfFrameName+1;
   end
end
end